aboutsummaryrefslogtreecommitdiffstats
path: root/home/item_price.asm
diff options
context:
space:
mode:
authorSylvie <35663410+Rangi42@users.noreply.github.com>2024-08-04 10:05:33 -0400
committerGitHub <noreply@github.com>2024-08-04 10:05:33 -0400
commit77d051479bd0ed96cc2efdba52f837afd1e119c3 (patch)
tree72a22aeb8dd6edc10323f0ee72fe9dbf73e5481a /home/item_price.asm
parentIdentify wcd6d as wNameBuffer and others (#455) (diff)
downloadpokeyellow-77d051479bd0ed96cc2efdba52f837afd1e119c3.tar.gz
pokeyellow-77d051479bd0ed96cc2efdba52f837afd1e119c3.tar.xz
pokeyellow-77d051479bd0ed96cc2efdba52f837afd1e119c3.zip
Identify wcf91 as wCurPartySpecies, wCurItem, and wCurListMenuItem (#457)
Diffstat (limited to 'home/item_price.asm')
-rw-r--r--home/item_price.asm4
1 files changed, 2 insertions, 2 deletions
diff --git a/home/item_price.asm b/home/item_price.asm
index 98eb31b1..a71f655f 100644
--- a/home/item_price.asm
+++ b/home/item_price.asm
@@ -1,6 +1,6 @@
GetItemPrice::
; Stores item's price as BCD at hItemPrice (3 bytes)
; Input: [wcf91] = item id
ldh a, [hLoadedROMBank]
push af
ld a, [wListMenuID]
@@ -15,7 +15,7 @@ GetItemPrice::
ld a, [hli]
ld h, [hl]
ld l, a
- ld a, [wcf91] ; a contains item id
+ ld a, [wCurItem]
cp HM01
jr nc, .getTMPrice
ld bc, $3
@@ -1,6 +1,6 @@
GetItemPrice::
; Stores item's price as BCD at hItemPrice (3 bytes)
-; Input: [wcf91] = item id
+; Input: [wCurItem] = item id
ldh a, [hLoadedROMBank]
push af